@@ -1,6 +1,6 @@
 /*
 
-  Copyright 2012-2021 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2022 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -30,6 +30,7 @@ class OGRSpatialReference;
 
 #include <cassert>
 #include <iostream>
+#include <utility>
 #include <vector>
 
 extern SRS srs;
@@ -46,14 +47,14 @@ static std::unique_ptr<OGRPolygon> create_rectangular_polygon(double x1, double
     // make sure we are inside the bounds for the output SRS
     e.Intersect(srs.max_extent());
 
-    std::unique_ptr<OGRLinearRing> ring{new OGRLinearRing()};
+    auto ring = std::make_unique<OGRLinearRing>();
     ring->addPoint(e.MinX, e.MinY);
     ring->addPoint(e.MinX, e.MaxY);
     ring->addPoint(e.MaxX, e.MaxY);
     ring->addPoint(e.MaxX, e.MinY);
     ring->closeRings();
 
-    std::unique_ptr<OGRPolygon> polygon{new OGRPolygon()};
+    auto polygon = std::make_unique<OGRPolygon>();
     polygon->addRingDirectly(ring.release());
     polygon->assignSpatialReference(srs.out());
 
@@ -133,6 +134,49 @@ void CoastlinePolygons::split_geometry(std::unique_ptr<OGRGeometry>&& geom, int
     }
 }
 
+std::pair<std::unique_ptr<OGRPolygon>, std::unique_ptr<OGRPolygon>> CoastlinePolygons::split_envelope(const OGREnvelope& envelope, int level, int num_points) const {
+    if (debug) {
+        std::cerr << "DEBUG: split_polygon(): depth="
+                  << level
+                  << " envelope=("
+                  << envelope.MinX << ", " << envelope.MinY
+                  << "),("
+                  << envelope.MaxX << ", " << envelope.MaxY
+                  << ") num_points="
+                  << num_points
+                  << "\n";
+    }
+
+    // These polygons will contain the bounding box of each half of the "polygon" polygon.
+    std::pair<std::unique_ptr<OGRPolygon>, std::unique_ptr<OGRPolygon>> envelopes;
+
+    if (envelope.MaxX - envelope.MinX < envelope.MaxY-envelope.MinY) {
+        if (m_expand >= (envelope.MaxY - envelope.MinY) / 4) {
+            std::cerr << "Not splitting polygon with " << num_points << " points on outer ring. It would not get smaller because --bbox-overlap/-b is set to high.\n";
+            return envelopes;
+        }
+
+        // split vertically
+        const double MidY = (envelope.MaxY + envelope.MinY) / 2;
+
+        envelopes.first = create_rectangular_polygon(envelope.MinX, envelope.MinY, envelope.MaxX, MidY, m_expand);
+        envelopes.second = create_rectangular_polygon(envelope.MinX, MidY, envelope.MaxX, envelope.MaxY, m_expand);
+    } else {
+        if (m_expand >= (envelope.MaxX - envelope.MinX) / 4) {
+            std::cerr << "Not splitting polygon with " << num_points << " points on outer ring. It would not get smaller because --bbox-overlap/-b is set to high.\n";
+            return envelopes;
+        }
+
+        // split horizontally
+        const double MidX = (envelope.MaxX + envelope.MinX) / 2;
+
+        envelopes.first = create_rectangular_polygon(envelope.MinX, envelope.MinY, MidX, envelope.MaxY, m_expand);
+        envelopes.second = create_rectangular_polygon(MidX, envelope.MinY, envelope.MaxX, envelope.MaxY, m_expand);
+    }
+
+    return envelopes;
+}
+
 void CoastlinePolygons::split_polygon(std::unique_ptr<OGRPolygon>&& polygon, int level) {
     if (level > m_max_split_depth) {
         m_max_split_depth = level;
@@ -142,78 +186,45 @@ void CoastlinePolygons::split_polygon(std::unique_ptr<OGRPolygon>&& polygon, int
     if (num_points <= m_max_points_in_polygon) {
         // do not split the polygon if it is small enough
         m_polygons.push_back(std::move(polygon));
-    } else {
-        OGREnvelope envelope;
-        polygon->getEnvelope(&envelope);
-        if (debug) {
-            std::cerr << "DEBUG: split_polygon(): depth="
-                      << level
-                      << " envelope=("
-                      << envelope.MinX << ", " << envelope.MinY
-                      << "),("
-                      << envelope.MaxX << ", " << envelope.MaxY
-                      << ") num_points="
-                      << num_points
-                      << "\n";
-        }
+        return;
+    }
 
-        // These polygons will contain the bounding box of each half of the "polygon" polygon.
-        std::unique_ptr<OGRPolygon> b1;
-        std::unique_ptr<OGRPolygon> b2;
+    OGREnvelope envelope;
+    polygon->getEnvelope(&envelope);
 
-        if (envelope.MaxX - envelope.MinX < envelope.MaxY-envelope.MinY) {
-            if (m_expand >= (envelope.MaxY - envelope.MinY) / 4) {
-                std::cerr << "Not splitting polygon with " << num_points << " points on outer ring. It would not get smaller because --bbox-overlap/-b is set to high.\n";
-                m_polygons.push_back(std::move(polygon));
-                return;
+    auto const split_envelopes = split_envelope(envelope, level, num_points);
+    if (!split_envelopes.first) {
+        m_polygons.push_back(std::move(polygon));
+        return;
+    }
+
+    // Use intersection with bbox polygons to split polygon into two halfes
+    std::unique_ptr<OGRGeometry> geom1{polygon->Intersection(split_envelopes.first.get())};
+    std::unique_ptr<OGRGeometry> geom2{polygon->Intersection(split_envelopes.second.get())};
+
+    if (geom1 && (geom1->getGeometryType() == wkbPolygon || geom1->getGeometryType() == wkbMultiPolygon) &&
+        geom2 && (geom2->getGeometryType() == wkbPolygon || geom2->getGeometryType() == wkbMultiPolygon)) {
+        // split was successful, go on recursively
+        split_geometry(std::move(geom1), level + 1);
+        split_geometry(std::move(geom2), level + 1);
+        return;
+    }
+
+    // split was not successful, output some debugging info and keep polygon before split
+    std::cerr << "Polygon split at depth " << level << " was not successful. Keeping un-split polygon.\n";
+    m_polygons.push_back(std::move(polygon));
+    if (debug) {
+        std::cerr << "DEBUG geom1=" << geom1.get() << " geom2=" << geom2.get() << "\n";
+        if (geom1) {
+            std::cerr << "DEBUG geom1 type=" << geom1->getGeometryName() << "\n";
+            if (geom1->getGeometryType() == wkbGeometryCollection) {
+                std::cerr << "DEBUG   numGeometries=" << static_cast<OGRGeometryCollection*>(geom1.get())->getNumGeometries() << "\n";
             }
-
-            // split vertically
-            const double MidY = (envelope.MaxY + envelope.MinY) / 2;
-
-            b1 = create_rectangular_polygon(envelope.MinX, envelope.MinY, envelope.MaxX, MidY, m_expand);
-            b2 = create_rectangular_polygon(envelope.MinX, MidY, envelope.MaxX, envelope.MaxY, m_expand);
-        } else {
-            if (m_expand >= (envelope.MaxX - envelope.MinX) / 4) {
-                std::cerr << "Not splitting polygon with " << num_points << " points on outer ring. It would not get smaller because --bbox-overlap/-b is set to high.\n";
-                m_polygons.push_back(std::move(polygon));
-                return;
-            }
-
-            // split horizontally
-            const double MidX = (envelope.MaxX + envelope.MinX) / 2;
-
-            b1 = create_rectangular_polygon(envelope.MinX, envelope.MinY, MidX, envelope.MaxY, m_expand);
-            b2 = create_rectangular_polygon(MidX, envelope.MinY, envelope.MaxX, envelope.MaxY, m_expand);
         }
-
-        // Use intersection with bbox polygons to split polygon into two halfes
-        std::unique_ptr<OGRGeometry> geom1{polygon->Intersection(b1.get())};
-        std::unique_ptr<OGRGeometry> geom2{polygon->Intersection(b2.get())};
-
-        if (geom1 && (geom1->getGeometryType() == wkbPolygon || geom1->getGeometryType() == wkbMultiPolygon) &&
-            geom2 && (geom2->getGeometryType() == wkbPolygon || geom2->getGeometryType() == wkbMultiPolygon)) {
-            // split was successful, go on recursively
-            split_geometry(std::move(geom1), level + 1);
-            split_geometry(std::move(geom2), level + 1);
-        } else {
-            // split was not successful, output some debugging info and keep polygon before split
-            std::cerr << "Polygon split at depth " << level << " was not successful. Keeping un-split polygon.\n";
-            m_polygons.push_back(std::move(polygon));
-            if (debug) {
-                std::cerr << "DEBUG geom1=" << geom1.get() << " geom2=" << geom2.get() << "\n";
-                if (geom1) {
-                    std::cerr << "DEBUG geom1 type=" << geom1->getGeometryName() << "\n";
-                    if (geom1->getGeometryType() == wkbGeometryCollection) {
-                        std::cerr << "DEBUG   numGeometries=" << static_cast<OGRGeometryCollection*>(geom1.get())->getNumGeometries() << "\n";
-                    }
-                }
-                if (geom2) {
-                    std::cerr << "DEBUG geom2 type=" << geom2->getGeometryName() << "\n";
-                    if (geom2->getGeometryType() == wkbGeometryCollection) {
-                        std::cerr << "DEBUG   numGeometries=" << static_cast<OGRGeometryCollection*>(geom2.get())->getNumGeometries() << "\n";
-                    }
-                }
+        if (geom2) {
+            std::cerr << "DEBUG geom2 type=" << geom2->getGeometryName() << "\n";
+            if (geom2->getGeometryType() == wkbGeometryCollection) {
+                std::cerr << "DEBUG   numGeometries=" << static_cast<OGRGeometryCollection*>(geom2.get())->getNumGeometries() << "\n";
             }
         }
     }
@@ -256,9 +267,9 @@ void CoastlinePolygons::output_polygon_ring_as_lines(int max_points, const OGRLi
     const int num = ring->getNumPoints();
     assert(num > 2);
 
-    std::unique_ptr<OGRPoint> point1{new OGRPoint};
-    std::unique_ptr<OGRPoint> point2{new OGRPoint};
-    std::unique_ptr<OGRLineString> line{new OGRLineString};
+    auto point1 = std::make_unique<OGRPoint>();
+    auto point2 = std::make_unique<OGRPoint>();
+    auto line = std::make_unique<OGRLineString>();
 
     ring->getPoint(0, point1.get());
     for (int i = 1; i < num; ++i) {
@@ -268,7 +279,7 @@ void CoastlinePolygons::output_polygon_ring_as_lines(int max_points, const OGRLi
 
         if (line->getNumPoints() >= max_points || !added) {
             if (line->getNumPoints() >= 2) {
-                std::unique_ptr<OGRLineString> new_line{new OGRLineString};
+                auto new_line = std::make_unique<OGRLineString>();
                 using std::swap;
                 swap(line, new_line);
                 add_line_to_output(std::move(new_line), ring->getSpatialReference());
@@ -293,16 +304,13 @@ void CoastlinePolygons::output_lines(int max_points) const {
     }
 }
 
-OGREnvelope env_west;
-OGREnvelope env_east;
-
 // Without this check there will be a very narrow sliver of water at the
 // antimeridian "cutting" into Antarctica. If this returns true, the geometry
 // is the polygon with this sliver and we don't add it to the output.
-static bool antarctica_bogus(const OGRGeometry* geom) noexcept {
+bool CoastlinePolygons::antarctica_bogus(const OGRGeometry* geom) noexcept {
     OGREnvelope envelope;
     geom->getEnvelope(&envelope);
-    return env_east.Contains(envelope) || env_west.Contains(envelope);
+    return m_env_east.Contains(envelope) || m_env_west.Contains(envelope);
 }
 
 void CoastlinePolygons::split_bbox(const OGREnvelope& envelope, polygon_vector_type&& v) {
@@ -324,7 +332,10 @@ void CoastlinePolygons::split_bbox(const OGREnvelope& envelope, polygon_vector_t
                 switch (geom->getGeometryType()) {
                     case wkbPolygon:
                         if (!antarctica_bogus(geom.get())) {
-                            m_output.add_water_polygon(static_cast_unique_ptr<OGRPolygon>(std::move(geom)));
+                            auto polygon = static_cast_unique_ptr<OGRPolygon>(std::move(geom));
+                            if (polygon->getExteriorRing()) {
+                                m_output.add_water_polygon(std::move(polygon));
+                            }
                         }
                         break;
                     case wkbMultiPolygon: {
@@ -451,25 +462,25 @@ unsigned int CoastlinePolygons::check_polygons() {
 
 void CoastlinePolygons::output_water_polygons() {
     if (srs.is_wgs84()) {
-        env_west.MinX = -180.0;
-        env_west.MinY =  -90.0;
-        env_west.MaxX = -179.9998;
-        env_west.MaxY =  -77.0;
+        m_env_west.MinX = -180.0;
+        m_env_west.MinY =  -90.0;
+        m_env_west.MaxX = -179.9998;
+        m_env_west.MaxY =  -77.0;
 
-        env_east.MinX =  179.9998;
-        env_east.MinY =  -90.0;
-        env_east.MaxX =  180.0;
-        env_east.MaxY =  -77.0;
+        m_env_east.MinX =  179.9998;
+        m_env_east.MinY =  -90.0;
+        m_env_east.MaxX =  180.0;
+        m_env_east.MaxY =  -77.0;
     } else {
-        env_west.MinX = -20037508.342789244;
-        env_west.MinY = -20037508.342789244;
-        env_west.MaxX = -20037499.0;
-        env_west.MaxY =  14230070.0;
+        m_env_west.MinX = -20037508.342789244;
+        m_env_west.MinY = -20037508.342789244;
+        m_env_west.MaxX = -20037499.0;
+        m_env_west.MaxY =  14230070.0;
 
-        env_east.MinX =  20037499.0;
-        env_east.MinY = -20037508.342789244;
-        env_east.MaxX =  20037508.342789244;
-        env_east.MaxY =  14230080.0;
+        m_env_east.MinX =  20037499.0;
+        m_env_east.MinY = -20037508.342789244;
+        m_env_east.MaxX =  20037508.342789244;
+        m_env_east.MaxY =  14230080.0;
     }
 
     split_bbox(srs.max_extent(), std::move(m_polygons));
