@@ -3,7 +3,7 @@
 
 /*
 
-  Copyright 2012-2021 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2022 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -64,6 +64,9 @@ class CoastlinePolygons {
      */
     polygon_vector_type m_polygons;
 
+    OGREnvelope m_env_west;
+    OGREnvelope m_env_east;
+
     /**
      * Max depth after recursive splitting.
      */
@@ -73,6 +76,8 @@ class CoastlinePolygons {
     void split_polygon(std::unique_ptr<OGRPolygon>&& polygon, int level);
     void split_bbox(const OGREnvelope& envelope, polygon_vector_type&& v);
 
+    std::pair<std::unique_ptr<OGRPolygon>, std::unique_ptr<OGRPolygon>> split_envelope(const OGREnvelope& envelope, int level, int num_points) const;
+
     void add_line_to_output(std::unique_ptr<OGRLineString> line, OGRSpatialReference* srs) const;
     void output_polygon_ring_as_lines(int max_points, const OGRLinearRing* ring) const;
 
@@ -119,6 +124,8 @@ public:
     /// Write all coastlines to the output database (as lines).
     void output_lines(int max_points) const;
 
+    bool antarctica_bogus(const OGRGeometry* geom) noexcept;
+
 }; // class CoastlinePolygons
 
 #endif // COASTLINE_POLYGONS_HPP
