@@ -1,6 +1,6 @@
 /*
 
-  Copyright 2012-2021 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2022 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -229,11 +229,11 @@ bool y_range_overlap(const osmium::UndirectedSegment& s1, const osmium::Undirect
     const int omin = s2.first().y() < s2.second().y() ? s2.first().y()  : s2.second().y();
     const int omax = s2.first().y() < s2.second().y() ? s2.second().y() : s2.first().y();
 
-    return !(tmin > omax || omin > tmax);
+    return tmin <= omax && omin <= tmax;
 }
 
 std::unique_ptr<OGRLineString> create_ogr_linestring(const osmium::Segment& segment) {
-    std::unique_ptr<OGRLineString> line{new OGRLineString};
+    auto line = std::make_unique<OGRLineString>();
     line->setNumPoints(2);
     line->setPoint(0, segment.first().lon(), segment.first().lat());
     line->setPoint(1, segment.second().lon(), segment.second().lat());
@@ -302,7 +302,7 @@ unsigned int CoastlineRingCollection::check_for_intersections(OutputDatabase& ou
                     break;
                 }
                 if (y_range_overlap(s1, s2)) {
-                    osmium::Location i = intersection(s1, s2);
+                    const auto i = intersection(s1, s2);
                     if (i) {
                         intersections.push_back(i);
                     }
@@ -312,7 +312,7 @@ unsigned int CoastlineRingCollection::check_for_intersections(OutputDatabase& ou
     }
 
     for (const auto& intersection : intersections) {
-        std::unique_ptr<OGRPoint> point{new OGRPoint(intersection.lon(), intersection.lat())};
+        auto point = std::make_unique<OGRPoint>(intersection.lon(), intersection.lat());
         output.add_error_point(std::move(point), "intersection");
     }
 
@@ -355,7 +355,7 @@ void CoastlineRingCollection::close_rings(OutputDatabase& output, bool debug, do
     // Go through vector starting with the shortest connections and close rings
     // using the connections in turn.
     while (!connections.empty()) {
-        Connection conn = connections.back();
+        const Connection conn = connections.back();
         connections.pop_back();
 
         // Invalidate all other connections using one of the same end points.
@@ -378,7 +378,7 @@ void CoastlineRingCollection::close_rings(OutputDatabase& output, bool debug, do
             output.add_error_point(s->ogr_first_point(), "fixed_end_point", s->first_node_id());
 
             if (e->last_location() != s->first_location()) {
-                std::unique_ptr<OGRLineString> linestring{new OGRLineString};
+                auto linestring = std::make_unique<OGRLineString>();
                 linestring->addPoint(e->last_location().lon(), e->last_location().lat());
                 linestring->addPoint(s->first_location().lon(), s->first_location().lat());
                 output.add_error_line(std::move(linestring), "added_line");
@@ -447,7 +447,7 @@ unsigned int CoastlineRingCollection::output_questionable(const CoastlinePolygon
     for (const auto& polygon : polygons) {
         const OGRLinearRing* exterior_ring = polygon->getExteriorRing();
         assert(exterior_ring);
-        osmium::Location pos{exterior_ring->getX(0), exterior_ring->getY(0)};
+        const osmium::Location pos{exterior_ring->getX(0), exterior_ring->getY(0)};
         const auto rings_it = lower_bound(rings.begin(), rings.end(), lcrp_type{pos, nullptr}, comp);
         if (rings_it != rings.end()) {
             rings_it->second->set_outer();
