@@ -1,6 +1,6 @@
 /*
 
-  Copyright 2012-2021 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2022 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -69,6 +69,42 @@ const unsigned int max_warnings = 500;
 
 /* ================================================== */
 
+void add_polygons_in_multi_to(polygon_vector_type *polygons,
+                              std::unique_ptr<OGRGeometry> mega_geometry,
+                              OutputDatabase& output,
+                              unsigned int* warnings, unsigned int* errors) {
+    // This isn't an owning pointer on purpose. We are going to "steal" parts
+    // of the geometry a few lines below but only mark them as unowned farther
+    // below when we are calling removeGeometry() on it. If this was an
+    // owning pointer we'd get a double free if there is an error.
+    auto* mega_multipolygon = static_cast<OGRMultiPolygon*>(mega_geometry.release());
+
+    polygons->reserve(mega_multipolygon->getNumGeometries());
+    for (int i = 0; i < mega_multipolygon->getNumGeometries(); ++i) {
+        OGRGeometry* geom = mega_multipolygon->getGeometryRef(i);
+        assert(geom);
+        assert(geom->getGeometryType() == wkbPolygon);
+        std::unique_ptr<OGRPolygon> p{static_cast<OGRPolygon*>(geom)};
+        if (p->IsValid()) {
+            polygons->push_back(std::move(p));
+        } else {
+            output.add_error_line(make_unique_ptr_clone<OGRLineString>(p->getExteriorRing()), "invalid");
+            std::unique_ptr<OGRGeometry> buf0{p->Buffer(0)};
+            if (buf0 && buf0->getGeometryType() == wkbPolygon && buf0->IsValid()) {
+                buf0->assignSpatialReference(srs.wgs84());
+                polygons->push_back(static_cast_unique_ptr<OGRPolygon>(std::move(buf0)));
+                (*warnings)++;
+            } else {
+                std::cerr << "Ignoring invalid polygon geometry.\n";
+                (*errors)++;
+            }
+        }
+    }
+
+    mega_multipolygon->removeGeometry(-1, FALSE);
+    delete mega_multipolygon; // NOLINT(cppcoreguidelines-owning-memory)
+}
+
 /**
  * This function assembles all the coastline rings into one huge multipolygon.
  */
@@ -84,7 +120,7 @@ polygon_vector_type create_polygons(CoastlineRingCollection& coastline_rings, Ou
     if (debug) {
         std::cerr << "Calling organizePolygons()\n";
     }
-    std::unique_ptr<OGRGeometry> mega_geometry{OGRGeometryFactory::organizePolygons(&all_polygons[0], all_polygons.size(), &is_valid, options)};
+    std::unique_ptr<OGRGeometry> mega_geometry{OGRGeometryFactory::organizePolygons(all_polygons.data(), static_cast<int>(all_polygons.size()), &is_valid, options)};
     if (debug) {
         std::cerr << "organizePolygons() done (" << (is_valid ? "valid" : "invalid") << ")\n";
     }
@@ -105,37 +141,7 @@ polygon_vector_type create_polygons(CoastlineRingCollection& coastline_rings, Ou
     } else if (mega_geometry->getGeometryType() != wkbMultiPolygon) {
         throw std::runtime_error{"mega geometry isn't a (multi)polygon. Something is very wrong!"};
     } else {
-
-        // This isn't an owning pointer on purpose. We are going to "steal" parts
-        // of the geometry a few lines below but only mark them as unowned farther
-        // below when we are calling removeGeometry() on it. If this was an
-        // owning pointer we'd get a double free if there is an error.
-        auto* mega_multipolygon = static_cast<OGRMultiPolygon*>(mega_geometry.release());
-
-        polygons.reserve(mega_multipolygon->getNumGeometries());
-        for (int i = 0; i < mega_multipolygon->getNumGeometries(); ++i) {
-            OGRGeometry* geom = mega_multipolygon->getGeometryRef(i);
-            assert(geom);
-            assert(geom->getGeometryType() == wkbPolygon);
-            std::unique_ptr<OGRPolygon> p{static_cast<OGRPolygon*>(geom)};
-            if (p->IsValid()) {
-                polygons.push_back(std::move(p));
-            } else {
-                output.add_error_line(make_unique_ptr_clone<OGRLineString>(p->getExteriorRing()), "invalid");
-                std::unique_ptr<OGRGeometry> buf0{p->Buffer(0)};
-                if (buf0 && buf0->getGeometryType() == wkbPolygon && buf0->IsValid()) {
-                    buf0->assignSpatialReference(srs.wgs84());
-                    polygons.push_back(static_cast_unique_ptr<OGRPolygon>(std::move(buf0)));
-                    (*warnings)++;
-                } else {
-                    std::cerr << "Ignoring invalid polygon geometry.\n";
-                    (*errors)++;
-                }
-            }
-        }
-
-        mega_multipolygon->removeGeometry(-1, FALSE);
-        delete mega_multipolygon; // NOLINT(cppcoreguidelines-owning-memory)
+        add_polygons_in_multi_to(&polygons, std::move(mega_geometry), output, warnings, errors);
     }
 
     return polygons;
@@ -145,7 +151,7 @@ polygon_vector_type create_polygons(CoastlineRingCollection& coastline_rings, Ou
 /* ================================================== */
 
 std::string memory_usage() {
-    osmium::MemoryUsage mem;
+    const osmium::MemoryUsage mem;
     std::ostringstream s;
     s << "Memory used: current: " << mem.current() << " MBytes, peak: " << mem.peak() << " MBytes\n";
     return s.str();
@@ -154,10 +160,10 @@ std::string memory_usage() {
 /* ================================================== */
 
 std::unique_ptr<OutputDatabase> open_output_database(const std::string& driver, const std::string& name, const bool create_index) try {
-    return std::unique_ptr<OutputDatabase>{new OutputDatabase{driver, name, srs, create_index}};
+    return std::make_unique<OutputDatabase>(driver, name, srs, create_index);
 } catch (const std::exception& e) {
     std::cerr << e.what() << '\n';
-    std::exit(return_code_fatal);
+    return nullptr;
 }
 
 /* ================================================== */
@@ -168,7 +174,11 @@ int main(int argc, char *argv[]) {
     unsigned int errors = 0;
 
     // Parse command line and setup 'options' object with them.
-    Options options{argc, argv};
+    Options options;
+    const int result_code = options.parse(argc, argv);
+    if (result_code >= 0) {
+        return result_code;
+    }
 
     // The vout object is an output stream we can write to instead of
     // std::cerr. Nothing is written if we are not in verbose mode.
@@ -184,7 +194,7 @@ int main(int argc, char *argv[]) {
     vout << "Using SRS " << options.epsg << " for output. (Change with the --srs/s option.)\n";
     if (!srs.set_output(options.epsg)) {
         std::cerr << "Setting up output transformation failed\n";
-        std::exit(return_code_fatal);
+        return return_code_fatal;
     }
 
     // Optionally set up segments file
@@ -194,7 +204,7 @@ int main(int argc, char *argv[]) {
         segments_fd = ::open(options.segmentfile.c_str(), O_WRONLY | O_CREAT, 0666); // NOLINT(hicpp-signed-bitwise)
         if (segments_fd == -1) {
             std::cerr << "Couldn't open file '" << options.segmentfile << "' (" << std::strerror(errno) << ")\n";
-            std::exit(return_code_fatal);
+            return return_code_fatal;
         }
     }
 
@@ -212,6 +222,9 @@ int main(int argc, char *argv[]) {
     }
 
     auto output_database = open_output_database(options.driver, options.output_database, options.create_index);
+    if (!output_database) {
+        return return_code_fatal;
+    }
 
     // The collection of all coastline rings we will be filling and then
     // operating on.
@@ -222,7 +235,7 @@ int main(int argc, char *argv[]) {
         // held by some intermediate datastructures is recovered after we don't
         // need them any more.
         vout << "Reading from file '" << options.inputfile << "'.\n";
-        osmium::io::File infile{options.inputfile};
+        const osmium::io::File infile{options.inputfile};
 
         vout << "Reading ways (1st pass through input file)...\n";
         osmium::io::Reader reader1{infile, osmium::osm_entity_bits::way};
@@ -278,18 +291,17 @@ int main(int argc, char *argv[]) {
         reader2.close();
     } catch (const std::exception& e) {
         std::cerr << e.what() << '\n';
-        std::exit(return_code_fatal);
+        return return_code_fatal;
     }
 
     try {
         vout << "Checking for missing locations...\n";
-        unsigned int missing_locations = coastline_rings.check_locations(options.debug);
+        const unsigned int missing_locations = coastline_rings.check_locations(options.debug);
         if (missing_locations) {
             vout << "  There are " << missing_locations << " locations missing. Check that input file contains all nodes needed.\n";
-            std::exit(return_code_error);
-        } else {
-            vout << "  All locations are there.\n";
+            return return_code_error;
         }
+        vout << "  All locations are there.\n";
 
         vout << memory_usage();
 
@@ -309,7 +321,7 @@ int main(int argc, char *argv[]) {
             vout << "  Did not find open Antarctica ring.\n";
         }
 
-        if (options.close_rings) {
+        if (options.close_distance > 0) {
             vout << "Close broken rings... (Use --close-distance/-c 0 if you do not want this.)\n";
             vout << "  Closing if distance between nodes smaller than " << options.close_distance << ". (Set this with --close-distance/-c.)\n";
             coastline_rings.close_rings(*output_database, options.debug, options.close_distance);
@@ -330,7 +342,7 @@ int main(int argc, char *argv[]) {
         }
     } catch (const std::exception& e) {
         std::cerr << e.what() << '\n';
-        std::exit(return_code_fatal);
+        return return_code_fatal;
     }
 
     if (options.output_polygons != output_polygon_type::none || options.output_lines) {
