@@ -1,6 +1,6 @@
 /*
 
-  Copyright 2012-2021 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2022 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -74,7 +74,7 @@ public:
         if (::fstat(m_fd, &s) != 0) {
             throw std::system_error{errno, std::system_category(), std::string{"Can't get file size for '"} + m_filename + "'"};
         }
-        return std::size_t(s.st_size);
+        return static_cast<std::size_t>(s.st_size);
     }
 
 }; // class InputFile
@@ -83,7 +83,7 @@ void print_help() {
 }
 
 void add_segment(gdalcpp::Layer& layer, int change, const osmium::UndirectedSegment& segment) {
-    auto linestring = std::unique_ptr<OGRLineString>{new OGRLineString()};
+    auto linestring = std::make_unique<OGRLineString>();
     linestring->addPoint(segment.first().lon(), segment.first().lat());
     linestring->addPoint(segment.second().lon(), segment.second().lat());
 
@@ -143,15 +143,15 @@ int main(int argc, char *argv[]) {
             case 'h': {
                 std::cout << "Usage: osmcoastline_segments [OPTIONS] SEGFILE1 SEGFILE2\n";
                 print_help();
-                std::exit(return_code_ok);
+                return return_code_ok;
             }
             case 'V':
                 std::cout << "osmcoastline_segments " << get_osmcoastline_long_version() << " / " << get_libosmium_version() << '\n'
-                          << "Copyright (C) 2012-2021  Jochen Topf <jochen@topf.org>\n"
+                          << "Copyright (C) 2012-2022  Jochen Topf <jochen@topf.org>\n"
                           << "License: GNU GENERAL PUBLIC LICENSE Version 3 <https://gnu.org/licenses/gpl.html>.\n"
                           << "This is free software: you are free to change and redistribute it.\n"
                           << "There is NO WARRANTY, to the extent permitted by law.\n";
-                std::exit(return_code_ok);
+                return return_code_ok;
             default:
                 break;
         }
@@ -159,18 +159,18 @@ int main(int argc, char *argv[]) {
 
     if (optind != argc - 2) {
         std::cerr << "Usage: " << argv[0] << " [OPTIONS] SEGFILE1 SEGFILE2\n";
-        std::exit(return_code_cmdline);
+        return return_code_cmdline;
     }
 
     try {
         segvec removed_segments;
         segvec added_segments;
 
-        InputFile file1{argv[optind]};
-        InputFile file2{argv[optind + 1]};
+        const InputFile file1{argv[optind]};
+        const InputFile file2{argv[optind + 1]};
 
-        osmium::util::TypedMemoryMapping<osmium::UndirectedSegment> m1{file1.size() / sizeof(osmium::UndirectedSegment), osmium::util::MemoryMapping::mapping_mode::readonly, file1.fd()};
-        osmium::util::TypedMemoryMapping<osmium::UndirectedSegment> m2{file2.size() / sizeof(osmium::UndirectedSegment), osmium::util::MemoryMapping::mapping_mode::readonly, file2.fd()};
+        const osmium::util::TypedMemoryMapping<osmium::UndirectedSegment> m1{file1.size() / sizeof(osmium::UndirectedSegment), osmium::util::MemoryMapping::mapping_mode::readonly, file1.fd()};
+        const osmium::util::TypedMemoryMapping<osmium::UndirectedSegment> m2{file2.size() / sizeof(osmium::UndirectedSegment), osmium::util::MemoryMapping::mapping_mode::readonly, file2.fd()};
 
         std::set_difference(m1.cbegin(), m1.cend(), m2.cbegin(), m2.cend(), std::back_inserter(removed_segments));
         std::set_difference(m2.cbegin(), m2.cend(), m1.cbegin(), m1.cend(), std::back_inserter(added_segments));
@@ -192,7 +192,9 @@ int main(int argc, char *argv[]) {
         return (removed_segments.empty() && added_segments.empty()) ? 0 : 1;
     } catch (const std::exception& e) {
         std::cerr << e.what() << '\n';
-        std::exit(return_code_fatal);
+        return return_code_fatal;
     }
+
+    return return_code_ok;
 }
 
