@@ -1,6 +1,6 @@
 /*
 
-  Copyright 2012-2021 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2022 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -109,22 +109,22 @@ int main(int argc, char* argv[]) {
     if (argc >= 2) {
         if (!std::strcmp(argv[1], "--help") || !std::strcmp(argv[1], "-h")) {
             std::cout << "Usage: osmcoastline_ways OSMFILE [WAYSDB]\n";
-            std::exit(return_code_ok);
+            return return_code_ok;
         }
 
         if (!std::strcmp(argv[1], "--version") || !std::strcmp(argv[1], "-V")) {
             std::cout << "osmcoastline_ways " << get_osmcoastline_long_version() << " / " << get_libosmium_version() << '\n'
-                      << "Copyright (C) 2012-2021  Jochen Topf <jochen@topf.org>\n"
+                      << "Copyright (C) 2012-2022  Jochen Topf <jochen@topf.org>\n"
                       << "License: GNU GENERAL PUBLIC LICENSE Version 3 <https://gnu.org/licenses/gpl.html>.\n"
                       << "This is free software: you are free to change and redistribute it.\n"
                       << "There is NO WARRANTY, to the extent permitted by law.\n";
-            std::exit(return_code_ok);
+            return return_code_ok;
         }
     }
 
     if (argc != 2 && argc != 3) {
         std::cerr << "Usage: osmcoastline_ways OSMFILE [WAYSDB]\n";
-        std::exit(return_code_cmdline);
+        return return_code_cmdline;
     }
 
     CPLSetConfigOption("OGR_SQLITE_SYNCHRONOUS", "OFF");
@@ -141,7 +141,7 @@ int main(int argc, char* argv[]) {
         index_type index_neg;
         location_handler_type location_handler{index_pos, index_neg};
 
-        osmium::io::File infile{input_osm_filename};
+        const osmium::io::File infile{input_osm_filename};
         osmium::io::Reader reader1{infile, osmium::osm_entity_bits::node};
         osmium::apply(reader1, location_handler);
         reader1.close();
@@ -154,7 +154,9 @@ int main(int argc, char* argv[]) {
         std::cerr << "Sum of way lengths: " << std::fixed << (coastline_ways_handler.sum_length() / 1000) << "km\n";
     } catch (const std::exception& e) {
         std::cerr << e.what() << '\n';
-        std::exit(return_code_fatal);
+        return return_code_fatal;
     }
+
+    return return_code_ok;
 }
 
