@@ -1,6 +1,6 @@
 /*
 
-  Copyright 2012-2021 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2022 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -107,7 +107,7 @@ void OutputDatabase::set_options(const Options& options) {
     m_dataset.exec(sql.str());
 }
 
-void OutputDatabase::set_meta(int runtime, int memory_usage, const Stats& stats) {
+void OutputDatabase::set_meta(std::time_t runtime, int memory_usage, const Stats& stats) {
     if (m_driver != "SQLite") {
         return;
     }
@@ -158,7 +158,7 @@ void OutputDatabase::add_error_line(std::unique_ptr<OGRLineString>&& linestring,
     feature.add_to_layer();
 }
 
-void OutputDatabase::add_ring(std::unique_ptr<OGRPolygon>&& polygon, int osm_id, unsigned int nways, unsigned int npoints, bool fixed) {
+void OutputDatabase::add_ring(std::unique_ptr<OGRPolygon>&& polygon, osmium::object_id_type osm_id, unsigned int nways, unsigned int npoints, bool fixed) {
     m_srs.transform(polygon.get());
 
     const bool land = polygon->getExteriorRing()->isClockwise();
@@ -176,19 +176,10 @@ void OutputDatabase::add_ring(std::unique_ptr<OGRPolygon>&& polygon, int osm_id,
            hope that it will always be available. We use the GEOSisValidReason()
            function from the GEOS C interface to get to the reason.
         */
-
-#if GDAL_VERSION_MAJOR == 1 && GDAL_VERSION_MINOR <= 10
-        GEOSGeom p{polygon->exportToGEOS()};
-        char* r = GEOSisValidReason(p);
-        std::string reason = r ? r : "";
-        GEOSFree(r);
-        GEOSGeom_destroy(p);
-#else
         GEOSContextHandle_t contextHandle = OGRGeometry::createGEOSContext();
         char* r = GEOSisValidReason(polygon->exportToGEOS(contextHandle));
         std::string reason = r ? r : "";
         OGRGeometry::freeGEOSContext(contextHandle);
-#endif
 
         if (!reason.empty()) {
             const std::size_t left_bracket = reason.find('[');
@@ -199,9 +190,9 @@ void OutputDatabase::add_ring(std::unique_ptr<OGRPolygon>&& polygon, int osm_id,
             double y = NAN;
             iss >> x;
             iss >> y;
-            reason = reason.substr(0, left_bracket);
+            reason.resize(left_bracket);
 
-            std::unique_ptr<OGRPoint> point{new OGRPoint()};
+            auto point = std::make_unique<OGRPoint>();
             point->assignSpatialReference(polygon->getSpatialReference());
             point->setX(x);
             point->setY(y);
@@ -216,7 +207,7 @@ void OutputDatabase::add_ring(std::unique_ptr<OGRPolygon>&& polygon, int osm_id,
     }
 
     gdalcpp::Feature feature{m_layer_rings, std::move(polygon)};
-    feature.set_field("osm_id", osm_id);
+    feature.set_field("osm_id", static_cast<int>(osm_id));
     feature.set_field("nways", static_cast<int>(nways));
     feature.set_field("npoints", static_cast<int>(npoints));
     feature.set_field("fixed", fixed);
