@@ -3,7 +3,7 @@
 
 /*
 
-  Copyright 2012-2021 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2022 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -53,7 +53,7 @@ public:
 
     public:
 
-        TransformationException(OGRErr error_code) :
+        explicit TransformationException(OGRErr error_code) :
             runtime_error("SRS transformation failed - OGRErr=" + std::to_string(error_code)) {
         }
 
